@@ -9,20 +9,24 @@ ROOT = pathlib.Path(__file__).resolve().parent
 
 INIT_PY = ROOT.joinpath("src", "resolvelib", "__init__.py")
 
-nox.options.sessions = ["lint", "tests-3.8"]
+nox.options.sessions = ["lint", "tests"]
+nox.options.reuse_existing_virtualenvs = True
 
 
-@nox.session(python="3.8")
+@nox.session
 def lint(session):
     session.install(".[lint]")
+
     session.run("black", "--check", ".")
-    session.run("flake8", "src", "tests", "noxfile.py")
+    session.run("flake8", ".")
 
 
-@nox.session(python=["3.8", "2.7"])
+@nox.session(python=["3.9", "3.8", "3.7", "3.6", "3.5", "2.7"])
 def tests(session):
     session.install(".[test]")
-    session.run("pytest", "tests")
+
+    files = session.posargs or ["tests"]
+    session.run("pytest", *files)
 
 
 def _write_package_version(v):
@@ -41,7 +45,7 @@ def _write_package_version(v):
         f.write("".join(lines))
 
 
-@nox.session(python="3.8", reuse_venv=True)
+@nox.session
 def release(session):
     session.install(".[release]")
 
@@ -93,7 +97,7 @@ def release(session):
         session.log(f"Releasing distributions to {options.repo}...")
         session.run("setl", "publish", "--repository", options.repo)
     else:
-        session.log(f"Building distributions locally since --repo is empty")
+        session.log("Building distributions locally since --repo is empty")
         session.run("setl", "publish", "--no-upload")
 
     if options.prebump:
